@@ -8,7 +8,7 @@ Sys::Path - supply autoconf style installation directories
 
 =head1 SYNOPSIS
 
-Paths for basic Unix instalation when Perl is in /usr/bin:
+Paths for basic Unix installation when Perl is in /usr/bin:
 
     use Sys::Path;
 
@@ -21,7 +21,7 @@ Paths for basic Unix instalation when Perl is in /usr/bin:
     print Sys::Path->sharedstatedir, "\n";
     # /var/lib
 
-Paths for Unix when Perl is in home dir /home/daxim/local/bin:
+Paths for Unix when Perl is in home folder /home/daxim/local/bin:
 
     print Sys::Path->sysconfdir, "\n";
     # /home/daxim/local/etc
@@ -55,7 +55,7 @@ during C<perl Build.PL> prompting. After L<Sys::Path> is configured and installe
 all programs using it can just read/use the paths.
 
 In addition L<Sys::Path> includes some functions that are related to modules
-build or instalation. For now there is only L<Module::Build> based L<Module::Build::SysPath>
+build or installation. For now there is only L<Module::Build> based L<Module::Build::SysPath>
 that uses L<Sys::Path>.
 
 =head1 BUILD TIME CONFIGURATION
@@ -69,7 +69,7 @@ that uses L<Sys::Path>.
 
 This is an experiment and lot of questions and concerns can come out about
 the paths configuration. Distributions build systems integration and the naming.
-And as this is early version thinks may change. For these purposes there
+And as this is early version things may change. For these purposes there
 is a mailing list L<http://lists.meon.sk/mailman/listinfo/sys-path>.
 
 =head2 WHY?
@@ -83,7 +83,7 @@ L<Sys::Path> follows this standard when it is possible. Or when Perl follows.
 Perl can be installed in many places. Most Linux distributions place Perl
 in F</usr/bin/perl> where FHS suggest. In this case the FHS folders are
 suggested in prompt when doing `C<perl Build.PL>`. In other cases for
-other folders or home-dir Perl distributions L<Sys::Path> will suggest
+other folders or home-folder Perl distributions L<Sys::Path> will suggest
 folders under Perl install prefix. (ex. F<c:\strawerry\> for the ones using
 Windows).
 
@@ -172,12 +172,18 @@ F</var/lib> - $localstatedir/lib
 The directory for installing modifiable architecture-independent data.
 See L<http://www.pathname.com/fhs/pub/fhs-2.3.html#VARLIBVARIABLESTATEINFORMATION>.
 
+=head3 srvdir
+
+F</srv> - $prefix/srv
+
+Data for services provided by system.
+See L<http://www.pathname.com/fhs/pub/fhs-2.3.html#SRVDATAFORSERVICESPROVIDEDBYSYSTEM>.
+
 =head3 webdir
 
 F</var/www> - $localstatedir/www
 
-Not defined by FHS but it is a place to put web page related (html, js,
-css, ...) files.
+Directory where distribution put static web files.
 
 =head2 HOW IT WORKS
 
@@ -198,7 +204,7 @@ See L<Sys::Path::SPc> for the implementation.
 use warnings;
 use strict;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use File::Spec;
 use Text::Diff 'diff';
@@ -224,6 +230,7 @@ use base 'Sys::Path::SPc';
     lockdir
     sharedstatedir
     webdir
+    srvdir
 
 =cut
 
@@ -231,7 +238,8 @@ use base 'Sys::Path::SPc';
 
 =head2 find_distribution_root(__PACKAGE__)
 
-Find the root folder of distribution by going up the folder structure.
+Find the root folder of a modules distribution by going up the
+folder structure.
 
 =cut
 
@@ -253,7 +261,11 @@ sub find_distribution_root {
     my @path = File::Spec->splitdir($module_filename);
     my @package_names = split('::',$module_name);
     @path = splice(@path,0,-1-@package_names);
-    while (not -d File::Spec->catdir(@path, 't')) {
+    while (
+        (not -d File::Spec->catdir(@path, 't'))
+        and (not -f File::Spec->catdir(@path, 'Build.PL'))
+        and (not -f File::Spec->catdir(@path, 'Makefile.PL'))
+    ) {
         pop @path;
         die 'failed to find distribution root'
             if not @path;
@@ -310,7 +322,7 @@ Configuration file `$dst_file'
 =head2 changed_since_install($dest_file, $file)
 
 Return if C<$dest_file> changed since install. If optional C<$file> is
-set then this one is compared agains install C<$dest_file> checksum.
+set then this one is compared against install C<$dest_file> checksum.
 
 =cut
 
@@ -350,6 +362,7 @@ sub install_checksums {
         return %conffiles_md5;
     }
     
+    # create empty json file if non available
     JSON::Util->encode({}, [ $checksums_filename ])
         if not -f $checksums_filename;
     
@@ -366,71 +379,20 @@ __END__
 
 L<Module::Build::SysPath>
 
-=head1 FAQ
-
-=head2 Why "SPc" ?
-
-1. it is short (much more than SysPatchConfig)
-
-2. it is weird
-
-3. it's so weird that it is uniq, so there will be no conflict. (hopefully)
-
 =head1 AUTHOR
 
 Jozef Kutej, C<< <jkutej at cpan.org> >>
 
 =head1 CONTRIBUTORS
  
-The following people have contributed to the Sys::Path by commiting their
+The following people have contributed to the Sys::Path by committing their
 code, sending patches, reporting bugs, asking questions, suggesting useful
-advices, nitpicking, chatting on IRC or commenting on my blog (in no particular
+advises, nitpicking, chatting on IRC or commenting on my blog (in no particular
 order):
 
     Lars Dɪᴇᴄᴋᴏᴡ 迪拉斯
     Emmanuel Rodriguez
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-sys-path at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Sys-Path>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-=head2 Mailing list
-
-L<http://lists.meon.sk/mailman/listinfo/sys-path>
-
-=head2 The rest
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Sys::Path
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Sys-Path>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Sys-Path>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Sys-Path>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Sys-Path>
-
-=back
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Jozef Kutej, all rights reserved.
@@ -441,4 +403,4 @@ under the same terms as Perl itself.
 
 =cut
 
-1; # End of Sys::Path
+1;
